@@ -316,8 +316,8 @@ class language_learner:
         self.report_path = self.generate_new_folder('L_report')
         self.record_path = self.generate_new_folder('L_record')
         self.source_path = self.generate_new_folder('L_source')
-        self.df = pd.read_csv (data_file,sep = '|')
-        self.df_backup = self.df.copy(deep=True)
+        # self.df = pd.read_csv (data_file,sep = '|')
+        # self.df_backup = self.df.copy(deep=True)
         # create widgets
         self.create_top()
         self.create_label_word()
@@ -378,6 +378,7 @@ class language_learner:
         self.label_word.configure(foreground="#7dcd66")
         self.label_word.configure(text='''Click [File]-->[Open] to load data.''')
         self.label_word.configure(font=self.font_s)
+        self.label_word.config(state= "disabled")
 
     def create_button_start(self):
         self.button_start = tk.Button(self.top)
@@ -393,6 +394,7 @@ class language_learner:
         self.button_start.configure(text='''Start''')
         self.button_start.configure(font=self.font_s)
         self.button_start.configure(command=self.button_start_callback)
+        self.button_start.config(state= "disabled")
 
     def create_button_record(self):
         self.button_record = tk.Button(self.top)
@@ -408,6 +410,7 @@ class language_learner:
         self.button_record.configure(text='''Record''')
         self.button_record.configure(font=self.font_s)
         self.button_record.configure(command=self.button_record_callback)
+        self.button_record.config(state= "disabled")
 
     def create_button_read(self):
         self.button_read = tk.Button(self.top)
@@ -423,6 +426,7 @@ class language_learner:
         self.button_read.configure(text='''Read''')
         self.button_read.configure(font=self.font_s)
         self.button_read.config(command = self.button_read_callback)
+        self.button_read.config(state= "disabled")
 
     def create_button_check(self):
         self.button_check = tk.Button(self.top)
@@ -439,6 +443,8 @@ class language_learner:
         self.button_check.configure(text='''Check''')
         self.button_check.configure(font=self.font_s)
         self.button_check.config(command = self.button_check_callback)
+        self.button_check.config(state= "disabled")
+
     def create_button_before(self):
         self.button_before = tk.Button(self.top)
         self.button_before.place(relx=0.84, rely=0.870, height=48, width=119)
@@ -453,6 +459,7 @@ class language_learner:
         self.button_before.configure(text='''Before''')
         self.button_before.configure(font=self.font_s)
         self.button_before.config(command = self.button_before_callback)
+        self.button_before.config(state= "disabled")
 
     def create_button_report(self):
         self.button_report = tk.Button(self.top)
@@ -468,6 +475,7 @@ class language_learner:
         self.button_report.configure(text='''Report''')
         self.button_report.configure(font=self.font_s)
         self.button_report.config(command = self.button_report_callback)
+        self.button_report.config(state= "disabled")
 
     def create_entry_rounds(self):
         self.rounds_val = tk.StringVar()
@@ -482,6 +490,7 @@ class language_learner:
         self.entry_rounds.configure(font=self.font_s)
         self.entry_rounds.configure(foreground="#afafaf")
         self.entry_rounds.configure(insertbackground="#afafaf")
+        self.entry_rounds.config(state= "disabled")
 
     def create_entry_timer(self):
         self.time_val = tk.StringVar()
@@ -495,6 +504,7 @@ class language_learner:
         self.entry_timer.configure(font=self.font_s)
         self.entry_timer.configure(foreground="#afafaf")
         self.entry_timer.configure(insertbackground="#afafaf")
+        self.entry_timer.config(state= "disabled")
 
     def create_top(self):
         _bgcolor = '#d9d9d9'  # X11 color: 'gray85'
@@ -774,6 +784,12 @@ class language_learner:
         'Input prority to select the content in database (Integer):',
         initialvalue=1,
         parent=self.top)
+        self.initialize_widgets_for_start()
+        self.generate_problem_list_from_database()
+        self.problem_index = 0
+        self.rounds_val.set(len(self.df_f))
+        self.button_start.config(text = 'Start')
+        self.button_start.config(state = 'normal')
         # print(type(self.content_priority))
     def menu_order_callback(self):
         res = messagebox.askquestion("Order",
@@ -795,7 +811,7 @@ class language_learner:
         self.problem_index = 0
         self.rounds_val.set(len(self.df_f))
         self.button_start.config(text = 'Start')
-
+        self.button_start.config(state = 'normal')
 
     def initialize_widgets_for_start(self):
         if self.time_val.get() != 'Timer':
